..
    This file is part of Invenio.
    Copyright (C) 2017-2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

.. _style-guide:

Style guide
===========

This style guide can to a large degree be fully automated by your editor.
See our :ref:`setting-up-your-environment` for help on how to setup your
editor.

Python
------
We follow `PEP-8 <https://www.python.org/dev/peps/pep-0008/>`_ and `PEP-257
<https://www.python.org/dev/peps/pep-0257/>`_ and sort imports via ``isort``.
Please plug corresponding linters such as ``flake8`` to your editor.

Indention style and whitespace
------------------------------
Each repository contains a ``.editorconfig`` that defines the indention style, character set, trimming of trailing whitespace and final new lines.
